Function iTool_Export_to_File,filename, oTool, source=source, graphic_id=graphic_id, scale_factor=scale_factor
;;======================================================================================
;; Parameter				DESCRIPTION										Acceptable Values (Default in Caps)
;;---------------------------------------------------------------------------------------------------------------------------------------------------
;; filename					Output File name
;; oTool					  The object reference of the iTool
;; source		 			 Item to export	 										[0 - 'BY IDENTIFIER', 1 - 'Current window', 2 - 'Current view']
;; item_id		  	 	     Full identifier of item to export
;; scale_factor		      Scale factor for file export

;; Returns 1 on successful write, 0 on failure.
;;
;; If SOURCE is not specified, the default value of 'By Identifier' is used which means that
;; a value for ITEM_ID must be provided. This would be done as shown below. Where the
;; ITEM_ID would be set to 'graphic_id'
;;
;;					; Retrieve the iTool identifier
;;					tool = itGetCurrent(tool=oTool)
;;					;obtain window reference:
;;					oWin=oTool->GetCurrentWindow()
;;					;obtain view reference:
;;					oView = oWin->GetCurrentView()
;;					graphic_id = oTool->FindIdentifiers('*image', /VISUALIZATIONS)
;;
;; No ITEM_ID is needed for SOURCE equal to 1 or 2 (current window or current view)
;;
;; One of the following suffixs' must be used as part of the filename specification since the
;  type of output file is determined only from the suffix used on the filename.
;; NOTE: It must match the suffix exactly, i.e. 'tif' and 'jpeg' will NOT work.
;;
;;  *.bmp - Windows Bitmap
;;  *.eps - Encapsulated Postscript
;;  *.emf - Windows Enhanced Metafile
;;  *.jpg - Joint Photographics Experts Group
;;  *.jp2 - JPEG2000
;;  *.gif - Graphics Interchange Format
;;  *.pict - Macintosh PICT File
;;  *.png - Portable Network Graphics
;;  *.tiff - Tag Image File Format

IF NOT (KEYWORD_SET(source)) then source = 0
IF NOT (KEYWORD_SET(scale_factor)) then scale_factor = 1.0

; Get the full identifier of the Export operation and then use that to get
; the object reference ID of the Export object.
idExport = oTool->FindIdentifiers('*export*', /operations,count=count)
oExport = oTool->GetByIdentifier(idExport)

; Since this is intended to be run in batch mode do not show the export user interface
oExport->SetProperty,show_execution_ui=0

; The type of export file that is created is determined by the filename suffix. Make sure that
; the suffix name matches those supported formats defined in the program header at top of this file.
oExport->SetProperty,filename=filename

; Specify the source of the item being exported. If it is "By Identifier"
; then you must provide the full identifier of the item.
oExport->SetProperty,source=source
IF (source EQ 0) THEN BEGIN
	; Make sure there is an item id specified when source = 0
	IF NOT (KEYWORD_SET(graphic_id)) THEN BEGIN
			res = DIALOG_MESSAGE('An item ID must be provided when source is "By Identifier" ', /error)
			RETURN,0
	ENDIF
	oExport->SetProperty,item_id=graphic_id
ENDIF

; Specify the scale factor to use in drawing the output
oExport->SetProperty,scale_factor=scale_factor

; Execute the insert legend operation:
success = oTool->DoAction(idExport)
if (success NE 1) then BEGIN
	res = DIALOG_MESSAGE('Error executing export operation', /error)
	RETURN,0
ENDIF

RETURN,1

END


